import path from 'path';
import { findUserModulePaths } from '../userModules/findUserModulePaths.js';
import { slash } from '../utils/slash.js';
export function importUserModules({ rootDir, fixturesDir, fixtureFileSuffix, ignore, }) {
    const { fixturePaths, decoratorPaths } = findUserModulePaths({
        rootDir,
        fixturesDir,
        fixtureFileSuffix,
        ignore,
    });
    return {
        fixtures: importModules(fixturePaths, rootDir),
        decorators: importModules(decoratorPaths, rootDir),
    };
}
function importModules(paths, rootDir) {
    const modules = paths.map(p => {
        // Converting to forward slashes on Windows is important because the
        // slashes are used for generating a sorted list of fixtures and
        // decorators.
        const relPath = slash(path.relative(rootDir, p));
        return { relPath, module: require(p) };
    });
    return modules.reduce((acc, { relPath, module }) => ({
        ...acc,
        [relPath]: module,
    }), {});
}
